Compute the multivariate posterior distribution of the means
between multiple groups, for multiple correlated peptides. The function
accounts for multiple imputations through the Draw identifier in the
dataset.
multi_posterior_mean(
data,
mu_0 = NULL,
lambda_0 = 1,
Sigma_0 = NULL,
nu_0 = 10,
vectorised = FALSE
)A tibble providing the parameters of the multivariate posterior t-distribution for the mean of the considered groups and draws for each peptide.
A tibble or data frame containing imputed data sets for all
groups. Required columns: Peptide, Group, Sample,
Output. If missing data have been estimated from multiple
imputations, each imputation should be identified in an optional
Draw column.
A vector, corresponding to the prior mean. If NULL, all groups are initialised with the same empirical mean for each peptide.
A number, corresponding to the prior covariance scaling parameter.
A matrix, corresponding to the prior covariance parameter. If NULL, the identity matrix will be used by default.
A number, corresponding to the prior degrees of freedom.
A boolean, indicating whether we should used a vectorised version of the function. Default when nb_peptides < 30. If nb_peptides > 30, there is a high risk that the vectorised version would be slower.