A tibble or data frame, detailing for each Peptide
and each Group, the value of the t-distribution parameters. The
expected format is typically a return from a posterior_mean() function.
Expected columns in the univariate case: mu, lambda,
alpha, beta. Expected columns in the multivariate case:
mu, lambda, Sigma, nu.